@@ -393,10 +393,10 @@ class ToolTabWidget(QtGui.QTabWidget):
         except:
             self.Version = ''
 
-        try:
-            self.Name = self.VarsGui.Get('cl_name')
-        except:
-            self.Name = 'Calculate Console'
+        #try:
+        #    self.Name = self.VarsGui.Get('cl_name')
+        #except:
+        self.Name = 'Calculate Console'
 
         self.new_con_txt = _('New connection')
         self.sys_update_pid = None
